'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const ApplicationHandler_1 = require("../application/ApplicationHandler");
const GlobalConfigProcessor_1 = require("../universal/GlobalConfigProcessor");
const DaemonHandler_1 = require("../daemon/DaemonHandler");
const pandora_hub_1 = require("pandora-hub");
const debugGlobalConfig_1 = require("./debugGlobalConfig");
const globalConfigProcessor = GlobalConfigProcessor_1.GlobalConfigProcessor.getInstance();
const { consoleLogger } = require('../../cli/util/cliUtils');
/**
 * Class DebugApplicationLoader
 * For a profile.js application to debugging
 */
class DebugApplicationLoader {
    constructor(representation) {
        this.representation = representation;
    }
    /**
     * Start debug application
     * @return {Promise<void>}
     */
    async start() {
        const daemonRunning = await DaemonHandler_1.isDaemonRunning();
        // start a IPC-Hub when no daemon
        if (!daemonRunning) {
            const ipcHub = new pandora_hub_1.Hub();
            await ipcHub.start();
        }
        globalConfigProcessor.getAllProperties();
        globalConfigProcessor.mergeProperties(debugGlobalConfig_1.default);
        process.env.PANDORA_CONFIG = (process.env.PANDORA_CONFIG ?
            process.env.PANDORA_CONFIG + ':' : '') + require.resolve('./debugGlobalConfig');
        process.env.PANDORA_DEV = 'true';
        process.env.NODE_ENV = process.env.NODE_ENV || 'local';
        const appName = this.representation.appName || 'debug';
        const options = Object.assign({}, this.representation, { appName });
        this.master = new ApplicationHandler_1.ApplicationHandler(options);
        const onProcessTerm = (sig) => {
            consoleLogger.log();
            consoleLogger.important(`Receive a signal ${sig}, trying to stop...`);
            this.stop().then(() => {
                process.exit(0);
            }).catch((err) => {
                consoleLogger.error(err);
                process.exit(1);
            });
        };
        this.master.start().then(() => {
            consoleLogger.important('Application start successful.');
            process.once('SIGQUIT', onProcessTerm.bind(null, 'SIGQUIT'));
            process.once('SIGTERM', onProcessTerm.bind(null, 'SIGTERM'));
            process.once('SIGINT', onProcessTerm.bind(null, 'SIGINT'));
        }).catch((err) => {
            consoleLogger.error(err);
        });
    }
    async stop() {
        if (this.master) {
            await this.master.stop();
        }
    }
}
exports.DebugApplicationLoader = DebugApplicationLoader;
//# sourceMappingURL=DebugApplicationLoader.js.map